@@ -1,9 +1,12 @@
 package App::IndonesianLocaleUtils;
 
 use 5.010001;
+use strict;
 
-our $DATE = '2021-05-07'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2024-09-30'; # DATE
+our $DIST = 'App-IndonesianLocaleUtils'; # DIST
+our $VERSION = '0.021'; # VERSION
 
 1;
 # ABSTRACT: CLIs related to Indonesian locale
@@ -20,7 +23,7 @@ App::IndonesianLocaleUtils - CLIs related to Indonesian locale
 
 =head1 VERSION
 
-This document describes version 0.02 of App::IndonesianLocaleUtils (from Perl distribution App-IndonesianLocaleUtils), released on 2021-05-07.
+This document describes version 0.021 of App::IndonesianLocaleUtils (from Perl distribution App-IndonesianLocaleUtils), released on 2024-09-30.
 
 =head1
 
@@ -44,6 +47,37 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-Indone
 
 Source repository is at L<https://github.com/perlancar/perl-App-IndonesianLocaleUtils>.
 
+=head1 SEE ALSO
+
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2024, 2015 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-IndonesianLocaleUtils>
@@ -52,17 +86,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 SEE ALSO
-
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2015 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
